Module blaxel.models.request_duration_over_time_metric
======================================================

Classes
-------

`RequestDurationOverTimeMetric(average: blaxel.types.Unset | float = <blaxel.types.Unset object>, p50: blaxel.types.Unset | float = <blaxel.types.Unset object>, p90: blaxel.types.Unset | float = <blaxel.types.Unset object>, p99: blaxel.types.Unset | float = <blaxel.types.Unset object>, timestamp: blaxel.types.Unset | str = <blaxel.types.Unset object>)`
:   Request duration over time metric
    
    Attributes:
        average (Union[Unset, float]): Average request duration
        p50 (Union[Unset, float]): P50 request duration
        p90 (Union[Unset, float]): P90 request duration
        p99 (Union[Unset, float]): P99 request duration
        timestamp (Union[Unset, str]): Timestamp
    
    Method generated by attrs for class RequestDurationOverTimeMetric.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `average: blaxel.types.Unset | float`
    :

    `p50: blaxel.types.Unset | float`
    :

    `p90: blaxel.types.Unset | float`
    :

    `p99: blaxel.types.Unset | float`
    :

    `timestamp: blaxel.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :